==> kubernetes-model-discovery-5.10.0-sources.jar: io/fabric8/kubernetes/api/model/discovery/v1/EndpointHintsFluentImpl.java <==
package io.fabric8.kubernetes.api.model.discovery.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class EndpointHintsFluentImpl<A extends io.fabric8.kubernetes.api.model.discovery.v1.EndpointHintsFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.discovery.v1.EndpointHintsFluent<A>{
  public EndpointHintsFluentImpl() {
  }
  public EndpointHintsFluentImpl(io.fabric8.kubernetes.api.model.discovery.v1.EndpointHints instance) {
    this.withForZones(instance.getForZones()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.util.List<io.fabric8.kubernetes.api.model.discovery.v1.ForZoneBuilder> forZones =  new java.util.ArrayList<io.fabric8.kubernetes.api.model.discovery.v1.ForZoneBuilder>();
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public A addToForZones(java.lang.Integer index,io.fabric8.kubernetes.api.model.discovery.v1.ForZone item) {
    if (this.forZones == null) {this.forZones = new java.util.ArrayList<io.fabric8.kubernetes.api.model.discovery.v1.ForZoneBuilder>();}
    io.fabric8.kubernetes.api.model.discovery.v1.ForZoneBuilder builder = new io.fabric8.kubernetes.api.model.discovery.v1.ForZoneBuilder(item);_visitables.get("forZones").add(index >= 0 ? index : _visitables.get("forZones").size(), builder);this.forZones.add(index >= 0 ? index : forZones.size(), builder); return (A)this;
  }
  public A setToForZones(java.lang.Integer index,io.fabric8.kubernetes.api.model.discovery.v1.ForZone item) {
    if (this.forZones == null) {this.forZones = new java.util.ArrayList<io.fabric8.kubernetes.api.model.discovery.v1.ForZoneBuilder>();}
    io.fabric8.kubernetes.api.model.discovery.v1.ForZoneBuilder builder = new io.fabric8.kubernetes.api.model.discovery.v1.ForZoneBuilder(item);
    if (index < 0 || index >= _visitables.get("forZones").size()) { _visitables.get("forZones").add(builder); } else { _visitables.get("forZones").set(index, builder);}
    if (index < 0 || index >= forZones.size()) { forZones.add(builder); } else { forZones.set(index, builder);}
     return (A)this;
  }
  public A addToForZones(io.fabric8.kubernetes.api.model.discovery.v1.ForZone... items) {
    if (this.forZones == null) {this.forZones = new java.util.ArrayList<io.fabric8.kubernetes.api.model.discovery.v1.ForZoneBuilder>();}
    for (io.fabric8.kubernetes.api.model.discovery.v1.ForZone item : items) {io.fabric8.kubernetes.api.model.discovery.v1.ForZoneBuilder builder = new io.fabric8.kubernetes.api.model.discovery.v1.ForZoneBuilder(item);_visitables.get("forZones").add(builder);this.forZones.add(builder);} return (A)this;
  }
  public A addAllToForZones(java.util.Collection<io.fabric8.kubernetes.api.model.discovery.v1.ForZone> items) {
    if (this.forZones == null) {this.forZones = new java.util.ArrayList<io.fabric8.kubernetes.api.model.discovery.v1.ForZoneBuilder>();}
    for (io.fabric8.kubernetes.api.model.discovery.v1.ForZone item : items) {io.fabric8.kubernetes.api.model.discovery.v1.ForZoneBuilder builder = new io.fabric8.kubernetes.api.model.discovery.v1.ForZoneBuilder(item);_visitables.get("forZones").add(builder);this.forZones.add(builder);} return (A)this;
  }
  public A removeFromForZones(io.fabric8.kubernetes.api.model.discovery.v1.ForZone... items) {
    for (io.fabric8.kubernetes.api.model.discovery.v1.ForZone item : items) {io.fabric8.kubernetes.api.model.discovery.v1.ForZoneBuilder builder = new io.fabric8.kubernetes.api.model.discovery.v1.ForZoneBuilder(item);_visitables.get("forZones").remove(builder);if (this.forZones != null) {this.forZones.remove(builder);}} return (A)this;
  }
  public A removeAllFromForZones(java.util.Collection<io.fabric8.kubernetes.api.model.discovery.v1.ForZone> items) {
    for (io.fabric8.kubernetes.api.model.discovery.v1.ForZone item : items) {io.fabric8.kubernetes.api.model.discovery.v1.ForZoneBuilder builder = new io.fabric8.kubernetes.api.model.discovery.v1.ForZoneBuilder(item);_visitables.get("forZones").remove(builder);if (this.forZones != null) {this.forZones.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromForZones(java.util.function.Predicate<io.fabric8.kubernetes.api.model.discovery.v1.ForZoneBuilder> predicate) {
    if (forZones == null) return (A) this;
    final Iterator<io.fabric8.kubernetes.api.model.discovery.v1.ForZoneBuilder> each = forZones.iterator();
    final List visitables = _visitables.get("forZones");
    while (each.hasNext()) {
      io.fabric8.kubernetes.api.model.discovery.v1.ForZoneBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildForZones instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.kubernetes.api.model.discovery.v1.ForZone> getForZones() {
    return build(forZones);
  }
  public java.util.List<io.fabric8.kubernetes.api.model.discovery.v1.ForZone> buildForZones() {
    return build(forZones);
  }
  public io.fabric8.kubernetes.api.model.discovery.v1.ForZone buildForZone(java.lang.Integer index) {
    return this.forZones.get(index).build();
  }
  public io.fabric8.kubernetes.api.model.discovery.v1.ForZone buildFirstForZone() {
    return this.forZones.get(0).build();
  }
  public io.fabric8.kubernetes.api.model.discovery.v1.ForZone buildLastForZone() {
    return this.forZones.get(forZones.size() - 1).build();
  }
  public io.fabric8.kubernetes.api.model.discovery.v1.ForZone buildMatchingForZone(java.util.function.Predicate<io.fabric8.kubernetes.api.model.discovery.v1.ForZoneBuilder> predicate) {
    for (io.fabric8.kubernetes.api.model.discovery.v1.ForZoneBuilder item: forZones) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public java.lang.Boolean hasMatchingForZone(java.util.function.Predicate<io.fabric8.kubernetes.api.model.discovery.v1.ForZoneBuilder> predicate) {
    for (io.fabric8.kubernetes.api.model.discovery.v1.ForZoneBuilder item: forZones) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withForZones(java.util.List<io.fabric8.kubernetes.api.model.discovery.v1.ForZone> forZones) {
    if (this.forZones != null) { _visitables.get("forZones").removeAll(this.forZones);}
    if (forZones != null) {this.forZones = new java.util.ArrayList<io.fabric8.kubernetes.api.model.discovery.v1.ForZoneBuilder>(); for (io.fabric8.kubernetes.api.model.discovery.v1.ForZone item : forZones){this.addToForZones(item);}} else { this.forZones = null;} return (A) this;
  }
  public A withForZones(io.fabric8.kubernetes.api.model.discovery.v1.ForZone... forZones) {
    if (this.forZones != null) {this.forZones.clear();}
    if (forZones != null) {for (io.fabric8.kubernetes.api.model.discovery.v1.ForZone item :forZones){ this.addToForZones(item);}} return (A) this;
  }
  public java.lang.Boolean hasForZones() {
    return forZones != null && !forZones.isEmpty();
  }
  public A addNewForZone(java.lang.String name) {
    return (A)addToForZones(new ForZone(name));
  }
  public io.fabric8.kubernetes.api.model.discovery.v1.EndpointHintsFluent.ForZonesNested<A> addNewForZone() {
    return new io.fabric8.kubernetes.api.model.discovery.v1.EndpointHintsFluentImpl.ForZonesNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.discovery.v1.EndpointHintsFluent.ForZonesNested<A> addNewForZoneLike(io.fabric8.kubernetes.api.model.discovery.v1.ForZone item) {
    return new io.fabric8.kubernetes.api.model.discovery.v1.EndpointHintsFluentImpl.ForZonesNestedImpl(-1, item);
  }
  public io.fabric8.kubernetes.api.model.discovery.v1.EndpointHintsFluent.ForZonesNested<A> setNewForZoneLike(java.lang.Integer index,io.fabric8.kubernetes.api.model.discovery.v1.ForZone item) {
    return new io.fabric8.kubernetes.api.model.discovery.v1.EndpointHintsFluentImpl.ForZonesNestedImpl(index, item);
  }
  public io.fabric8.kubernetes.api.model.discovery.v1.EndpointHintsFluent.ForZonesNested<A> editForZone(java.lang.Integer index) {
    if (forZones.size() <= index) throw new RuntimeException("Can't edit forZones. Index exceeds size.");
    return setNewForZoneLike(index, buildForZone(index));
  }
  public io.fabric8.kubernetes.api.model.discovery.v1.EndpointHintsFluent.ForZonesNested<A> editFirstForZone() {
    if (forZones.size() == 0) throw new RuntimeException("Can't edit first forZones. The list is empty.");
    return setNewForZoneLike(0, buildForZone(0));
  }
  public io.fabric8.kubernetes.api.model.discovery.v1.EndpointHintsFluent.ForZonesNested<A> editLastForZone() {
    int index = forZones.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last forZones. The list is empty.");
    return setNewForZoneLike(index, buildForZone(index));
  }
  public io.fabric8.kubernetes.api.model.discovery.v1.EndpointHintsFluent.ForZonesNested<A> editMatchingForZone(java.util.function.Predicate<io.fabric8.kubernetes.api.model.discovery.v1.ForZoneBuilder> predicate) {
    int index = -1;
    for (int i=0;i<forZones.size();i++) { 
    if (predicate.test(forZones.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching forZones. No match found.");
    return setNewForZoneLike(index, buildForZone(index));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    EndpointHintsFluentImpl that = (EndpointHintsFluentImpl) o;
    if (forZones != null ? !forZones.equals(that.forZones) :that.forZones != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(forZones,  additionalProperties,  super.hashCode());
  }
  public class ForZonesNestedImpl<N> extends io.fabric8.kubernetes.api.model.discovery.v1.ForZoneFluentImpl<io.fabric8.kubernetes.api.model.discovery.v1.EndpointHintsFluent.ForZonesNested<N>> implements io.fabric8.kubernetes.api.model.discovery.v1.EndpointHintsFluent.ForZonesNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ForZonesNestedImpl(java.lang.Integer index,io.fabric8.kubernetes.api.model.discovery.v1.ForZone item) {
      this.index = index;
      this.builder = new io.fabric8.kubernetes.api.model.discovery.v1.ForZoneBuilder(this, item);
    }
    ForZonesNestedImpl() {
      this.index = -1;
      this.builder = new io.fabric8.kubernetes.api.model.discovery.v1.ForZoneBuilder(this);
    }
    io.fabric8.kubernetes.api.model.discovery.v1.ForZoneBuilder builder;
    java.lang.Integer index;
    public N and() {
      return (N) EndpointHintsFluentImpl.this.setToForZones(index,builder.build());
    }
    public N endForZone() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-discovery-5.12.4-sources.jar: io/fabric8/kubernetes/api/model/discovery/v1/EndpointHintsFluentImpl.java <==
package io.fabric8.kubernetes.api.model.discovery.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class EndpointHintsFluentImpl<A extends io.fabric8.kubernetes.api.model.discovery.v1.EndpointHintsFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.discovery.v1.EndpointHintsFluent<A>{
  public EndpointHintsFluentImpl() {
  }
  public EndpointHintsFluentImpl(io.fabric8.kubernetes.api.model.discovery.v1.EndpointHints instance) {
    this.withForZones(instance.getForZones()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.util.List<io.fabric8.kubernetes.api.model.discovery.v1.ForZoneBuilder> forZones =  new java.util.ArrayList<io.fabric8.kubernetes.api.model.discovery.v1.ForZoneBuilder>();
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public A addToForZones(java.lang.Integer index,io.fabric8.kubernetes.api.model.discovery.v1.ForZone item) {
    if (this.forZones == null) {this.forZones = new java.util.ArrayList<io.fabric8.kubernetes.api.model.discovery.v1.ForZoneBuilder>();}
    io.fabric8.kubernetes.api.model.discovery.v1.ForZoneBuilder builder = new io.fabric8.kubernetes.api.model.discovery.v1.ForZoneBuilder(item);_visitables.get("forZones").add(index >= 0 ? index : _visitables.get("forZones").size(), builder);this.forZones.add(index >= 0 ? index : forZones.size(), builder); return (A)this;
  }
  public A setToForZones(java.lang.Integer index,io.fabric8.kubernetes.api.model.discovery.v1.ForZone item) {
    if (this.forZones == null) {this.forZones = new java.util.ArrayList<io.fabric8.kubernetes.api.model.discovery.v1.ForZoneBuilder>();}
    io.fabric8.kubernetes.api.model.discovery.v1.ForZoneBuilder builder = new io.fabric8.kubernetes.api.model.discovery.v1.ForZoneBuilder(item);
    if (index < 0 || index >= _visitables.get("forZones").size()) { _visitables.get("forZones").add(builder); } else { _visitables.get("forZones").set(index, builder);}
    if (index < 0 || index >= forZones.size()) { forZones.add(builder); } else { forZones.set(index, builder);}
     return (A)this;
  }
  public A addToForZones(io.fabric8.kubernetes.api.model.discovery.v1.ForZone... items) {
    if (this.forZones == null) {this.forZones = new java.util.ArrayList<io.fabric8.kubernetes.api.model.discovery.v1.ForZoneBuilder>();}
    for (io.fabric8.kubernetes.api.model.discovery.v1.ForZone item : items) {io.fabric8.kubernetes.api.model.discovery.v1.ForZoneBuilder builder = new io.fabric8.kubernetes.api.model.discovery.v1.ForZoneBuilder(item);_visitables.get("forZones").add(builder);this.forZones.add(builder);} return (A)this;
  }
  public A addAllToForZones(java.util.Collection<io.fabric8.kubernetes.api.model.discovery.v1.ForZone> items) {
    if (this.forZones == null) {this.forZones = new java.util.ArrayList<io.fabric8.kubernetes.api.model.discovery.v1.ForZoneBuilder>();}
    for (io.fabric8.kubernetes.api.model.discovery.v1.ForZone item : items) {io.fabric8.kubernetes.api.model.discovery.v1.ForZoneBuilder builder = new io.fabric8.kubernetes.api.model.discovery.v1.ForZoneBuilder(item);_visitables.get("forZones").add(builder);this.forZones.add(builder);} return (A)this;
  }
  public A removeFromForZones(io.fabric8.kubernetes.api.model.discovery.v1.ForZone... items) {
    for (io.fabric8.kubernetes.api.model.discovery.v1.ForZone item : items) {io.fabric8.kubernetes.api.model.discovery.v1.ForZoneBuilder builder = new io.fabric8.kubernetes.api.model.discovery.v1.ForZoneBuilder(item);_visitables.get("forZones").remove(builder);if (this.forZones != null) {this.forZones.remove(builder);}} return (A)this;
  }
  public A removeAllFromForZones(java.util.Collection<io.fabric8.kubernetes.api.model.discovery.v1.ForZone> items) {
    for (io.fabric8.kubernetes.api.model.discovery.v1.ForZone item : items) {io.fabric8.kubernetes.api.model.discovery.v1.ForZoneBuilder builder = new io.fabric8.kubernetes.api.model.discovery.v1.ForZoneBuilder(item);_visitables.get("forZones").remove(builder);if (this.forZones != null) {this.forZones.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromForZones(java.util.function.Predicate<io.fabric8.kubernetes.api.model.discovery.v1.ForZoneBuilder> predicate) {
    if (forZones == null) return (A) this;
    final Iterator<io.fabric8.kubernetes.api.model.discovery.v1.ForZoneBuilder> each = forZones.iterator();
    final List visitables = _visitables.get("forZones");
    while (each.hasNext()) {
      io.fabric8.kubernetes.api.model.discovery.v1.ForZoneBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildForZones instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.kubernetes.api.model.discovery.v1.ForZone> getForZones() {
    return build(forZones);
  }
  public java.util.List<io.fabric8.kubernetes.api.model.discovery.v1.ForZone> buildForZones() {
    return build(forZones);
  }
  public io.fabric8.kubernetes.api.model.discovery.v1.ForZone buildForZone(java.lang.Integer index) {
    return this.forZones.get(index).build();
  }
  public io.fabric8.kubernetes.api.model.discovery.v1.ForZone buildFirstForZone() {
    return this.forZones.get(0).build();
  }
  public io.fabric8.kubernetes.api.model.discovery.v1.ForZone buildLastForZone() {
    return this.forZones.get(forZones.size() - 1).build();
  }
  public io.fabric8.kubernetes.api.model.discovery.v1.ForZone buildMatchingForZone(java.util.function.Predicate<io.fabric8.kubernetes.api.model.discovery.v1.ForZoneBuilder> predicate) {
    for (io.fabric8.kubernetes.api.model.discovery.v1.ForZoneBuilder item: forZones) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public java.lang.Boolean hasMatchingForZone(java.util.function.Predicate<io.fabric8.kubernetes.api.model.discovery.v1.ForZoneBuilder> predicate) {
    for (io.fabric8.kubernetes.api.model.discovery.v1.ForZoneBuilder item: forZones) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withForZones(java.util.List<io.fabric8.kubernetes.api.model.discovery.v1.ForZone> forZones) {
    if (this.forZones != null) { _visitables.get("forZones").removeAll(this.forZones);}
    if (forZones != null) {this.forZones = new java.util.ArrayList(); for (io.fabric8.kubernetes.api.model.discovery.v1.ForZone item : forZones){this.addToForZones(item);}} else { this.forZones = null;} return (A) this;
  }
  public A withForZones(io.fabric8.kubernetes.api.model.discovery.v1.ForZone... forZones) {
    if (this.forZones != null) {this.forZones.clear();}
    if (forZones != null) {for (io.fabric8.kubernetes.api.model.discovery.v1.ForZone item :forZones){ this.addToForZones(item);}} return (A) this;
  }
  public java.lang.Boolean hasForZones() {
    return forZones != null && !forZones.isEmpty();
  }
  public A addNewForZone(java.lang.String name) {
    return (A)addToForZones(new ForZone(name));
  }
  public io.fabric8.kubernetes.api.model.discovery.v1.EndpointHintsFluent.ForZonesNested<A> addNewForZone() {
    return new io.fabric8.kubernetes.api.model.discovery.v1.EndpointHintsFluentImpl.ForZonesNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.discovery.v1.EndpointHintsFluent.ForZonesNested<A> addNewForZoneLike(io.fabric8.kubernetes.api.model.discovery.v1.ForZone item) {
    return new io.fabric8.kubernetes.api.model.discovery.v1.EndpointHintsFluentImpl.ForZonesNestedImpl(-1, item);
  }
  public io.fabric8.kubernetes.api.model.discovery.v1.EndpointHintsFluent.ForZonesNested<A> setNewForZoneLike(java.lang.Integer index,io.fabric8.kubernetes.api.model.discovery.v1.ForZone item) {
    return new io.fabric8.kubernetes.api.model.discovery.v1.EndpointHintsFluentImpl.ForZonesNestedImpl(index, item);
  }
  public io.fabric8.kubernetes.api.model.discovery.v1.EndpointHintsFluent.ForZonesNested<A> editForZone(java.lang.Integer index) {
    if (forZones.size() <= index) throw new RuntimeException("Can't edit forZones. Index exceeds size.");
    return setNewForZoneLike(index, buildForZone(index));
  }
  public io.fabric8.kubernetes.api.model.discovery.v1.EndpointHintsFluent.ForZonesNested<A> editFirstForZone() {
    if (forZones.size() == 0) throw new RuntimeException("Can't edit first forZones. The list is empty.");
    return setNewForZoneLike(0, buildForZone(0));
  }
  public io.fabric8.kubernetes.api.model.discovery.v1.EndpointHintsFluent.ForZonesNested<A> editLastForZone() {
    int index = forZones.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last forZones. The list is empty.");
    return setNewForZoneLike(index, buildForZone(index));
  }
  public io.fabric8.kubernetes.api.model.discovery.v1.EndpointHintsFluent.ForZonesNested<A> editMatchingForZone(java.util.function.Predicate<io.fabric8.kubernetes.api.model.discovery.v1.ForZoneBuilder> predicate) {
    int index = -1;
    for (int i=0;i<forZones.size();i++) { 
    if (predicate.test(forZones.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching forZones. No match found.");
    return setNewForZoneLike(index, buildForZone(index));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    EndpointHintsFluentImpl that = (EndpointHintsFluentImpl) o;
    if (forZones != null ? !forZones.equals(that.forZones) :that.forZones != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(forZones,  additionalProperties,  super.hashCode());
  }
  public class ForZonesNestedImpl<N> extends io.fabric8.kubernetes.api.model.discovery.v1.ForZoneFluentImpl<io.fabric8.kubernetes.api.model.discovery.v1.EndpointHintsFluent.ForZonesNested<N>> implements io.fabric8.kubernetes.api.model.discovery.v1.EndpointHintsFluent.ForZonesNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ForZonesNestedImpl(java.lang.Integer index,io.fabric8.kubernetes.api.model.discovery.v1.ForZone item) {
      this.index = index;
      this.builder = new io.fabric8.kubernetes.api.model.discovery.v1.ForZoneBuilder(this, item);
    }
    ForZonesNestedImpl() {
      this.index = -1;
      this.builder = new io.fabric8.kubernetes.api.model.discovery.v1.ForZoneBuilder(this);
    }
    io.fabric8.kubernetes.api.model.discovery.v1.ForZoneBuilder builder;
    java.lang.Integer index;
    public N and() {
      return (N) EndpointHintsFluentImpl.this.setToForZones(index,builder.build());
    }
    public N endForZone() {
      return and();
    }
    
  }
  
}
